<?php
// $Id$
/**
 * Callback function to supply a list of content types.
 */
function uc_panels_uc_price_ctools_content_types() {
  return array(
    'single' => TRUE,
    'title' => t('Ubercart: Product Price'),
    'icon' => 'icon_node.png',
    'description' => t('Render the price for the related product node'),
    'required context' => new ctools_context_required(t('Ubercart Product'), 'uc'),
    'category' => t('Ubercart'),
    'defaults' => array('uc_price_option' => 'sell_price', 'uc_price_override_display' => FALSE),
  );
}

/**
 * Render the description
 */
function uc_panels_uc_price_content_type_render($subtype, $conf, $panel_args, $context) {
  if (empty($context) || empty($context->data)) {
    return;
  }

  // Get a shortcut to the node.
  $node = $context->data;
  
  $context = array(
    'revision' => 'themed',
    'type' => 'product',
    'class' => array(
      'product',
    ),
    'subject' => array(
      'node' => $node,
    ),
  );
  $uc_context['class'][1] = 'display';

  $option_titles = array(
    'sell_price' => t('Sell Price'), 
    'list_price' => t('List Price'), 
    'cost' => t('Cost'),
    'list_sell_diff' => t('You save'),
  );
  // get the $title, $price and $css values depending on the configured price option
  switch ($conf['uc_price_option']) {
    case 'sell_price': 
      $title = t('Price');
      $price = $node->sell_price;
      $css = '';
      $css = 'pane-uc-sell-price';
      break;
    case 'list_price':
      if (!$conf['uc_price_override_display']) {
        if (($node->list_price==0) || ($node->list_price < $node->sell_price)) {
          // hide panel if list price is zero or less than the sell price
          return;
        }
      }
      $title = t('List Price');
      $price = $node->list_price;
      $css = 'pane-uc-list-price';
      break;
    case 'cost':
      $title = t('Cost');
      $price = $node->cost;
      $css = 'pane-uc-cost';
      break;
    case 'you_save':
      if (($node->list_price==0) || ($node->list_price < $node->sell_price)) {
        // hide panel if list price is zero or less than the sell price
        return;
      }
      $title = t('You save');
      $price = $node->list_price - $node->sell_price;
      $css = 'pane-uc-you-save';
      break;
    default:
      $title = t('Price');
      $price = 0;
      $css = '';
  }
  
  // Build the content type block.
  $block = new stdClass();
  $block->title   = $title;
  $block->content = theme('uc_product_price', $price, $uc_context);
  $block->delta   = $node->nid;
  $block->css_class = $css;
  return $block;
}

/**
 * Edit form for the description content type.
 */
function uc_panels_uc_price_content_type_edit_form(&$form, &$form_state) {
  // The current configuration
  $conf = $form_state['conf'];
  
  $options = array(
    'sell_price' => t('Sell Price'), 
    'list_price' => t('List Price'), 
    'cost' => t('Cost'),
    'you_save' => t('Difference between List and Sell price'),
  );
    
  $form['uc_price_option'] = array(
    '#type' => 'select',
    '#title' => t('Price option'),
    '#description' => t('Which price to show'),
    '#default_value' => $conf['uc_price_option'],
    '#options' => $options,
  );
  $form['uc_price_override_display'] = array(
    '#type' => 'checkbox',
    '#title' => t('Override Display of Price'),
    '#description' => t('Enable this if you want the list price to always show up, regardless of being zero or less than the sell price.'),
    '#default_value' => $conf['uc_price_override_display'],
  );
}
/**
 * Edit form for the description content type.
 */
function uc_panels_uc_price_content_type_edit_form_submit(&$form, &$form_state) {
  // copy the value from the form into the array of items to be saved.
  foreach (array_keys($form_state['plugin']['defaults']) as $key) {
    $form_state['conf'][$key] = $form_state['values'][$key];
  }
}


/**
 * Returns the administrative title for a type.
 */
function uc_panels_uc_price_content_type_admin_title($subtype, $conf, $context) {
  switch ($conf['uc_price_option']) {
    case 'sell_price': 
      $title = t('Price');
      break;
    case 'list_price':
      $title = t('List Price');
      break; 
    case 'cost':
      $title = t('Cost');
      break;
    case 'you_save':
      $title = t('You save');
      break;
    default:
      $title = t('Price');
  }
  return ($title);
}